@@ -136,18 +136,15 @@ KDE_NO_EXPORT bool MediaInfo::wget (const String &str) {
         ImageDataMap::iterator i = image_data_map->find (str);
         if (i != image_data_map->end ()) {
             media = new ImageActor (node, i->second);
+            type = ActorAgent::Image;
             ready ();
             return true;
         }
     }
 
     Mrl *mrl = node->mrl ();
-    bool only_playlist = false;
-    bool maybe_playlist = false;
-
     if (mrl && (ActorAgent::Any == type || ActorAgent::AudioVideo == type))
     {
-        only_playlist = true;
         mime = mrl->mimetype;
 #ifdef __ARMEL__
         if (NpPlayer::isFlashMimeType (mime)) {
@@ -159,12 +156,18 @@ KDE_NO_EXPORT bool MediaInfo::wget (const String &str) {
 
     URL uri (str);
     if (mime.isEmpty () && uri.isLocalFile ()) {
-        mime = MimeType::findByURL (uri);
+        setMimetype (MimeType::findByURL (uri));
         if (mrl)
             mrl->mimetype = mime;
     }
-    if (!mime.isEmpty ())
-        maybe_playlist = isPlayListMime (mime);
+
+    bool only_playlist = false;
+    bool maybe_playlist = false;
+    if (ActorAgent::Audio == type || ActorAgent::AudioVideo == type) {
+        only_playlist = true;
+        if (!mime.isEmpty ())
+            maybe_playlist = isPlayListMime (mime);
+    }
 
     if (mrl) {
         if (mime.isEmpty ()) {
@@ -346,6 +349,19 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
     return !cur_elm->isPlayable ();
 }
 
+void MediaInfo::setMimetype (const String &mt)
+{
+    mime = mt;
+    if (!mt.isEmpty () && ActorAgent::Any == type) {
+        if (mimetype ().startsWith ("image/"))
+            type = ActorAgent::Image;
+        else if (mime.startsWith ("audio/"))
+            type = ActorAgent::Audio;
+        else
+            type = ActorAgent::AudioVideo;
+    }
+}
+
 KDE_NO_EXPORT String MediaInfo::mimetype () {
     if (data.size () > 0 && mime.isEmpty ())
         mime = MimeType::findByContent (data.data (), data.size ());
@@ -405,6 +421,8 @@ KDE_NO_EXPORT void MediaInfo::ready () {
 }
 
 static bool validDataFormat (ActorAgent::ActorType type, const ByteArray &ba) {
+    int sz = ba.size () > 512 ? 512 : ba.size();
+
     switch (type) {
     case ActorAgent::Any:
         //TODO
@@ -414,7 +432,6 @@ static bool validDataFormat (ActorAgent::ActorType type, const ByteArray &ba) {
                 (ba.size () > 4 &&
                  !strncmp (ba.data (), "RIFF", 4))); // falsely seen as text
         if (!kill && ba.size() > 14) {
-            int sz = ba.size () > 512 ? 512 : ba.size();
             String ct = MimeType::findByContent (ba.data(), sz);
             kill = !ct.startsWith ("text/") ||
                 (!strncasecmp (ba.data (), "<html", 5) || // html admin
@@ -432,7 +449,10 @@ KDE_NO_EXPORT void MediaInfo::jobResult (IOJob *jb) {
         data.resize (0);
     job = 0L; // signal KIO::IOJob::result deletes itself
     if (mime.isEmpty ()) {
-        mime = jb->contentType ();
+        if (ActorAgent::Any == type && data.size () >= 512)
+            setMimetype (MimeType::findByContent (data.data(), 512));
+        else
+            setMimetype (jb->contentType ());
         if (node->mrl ()) {
             node->mrl ()->mimetype = mime;
             node->mrl ()->audio_only = isAudioOnlyMime (mime);
@@ -450,9 +470,13 @@ KDE_NO_EXPORT void MediaInfo::jobData (IOJob *jb, ByteArray &ba) {
         data.resize (newsize);
         memcpy (data.data () + old_size, ba.data (), ba.size ());
 
-        if (old_size < 512 && newsize >= 512 && !validDataFormat (type, data)) {
-            data.resize (0);
-            job->kill (false); // not quiet, wants jobResult
+        if (old_size < 512 && newsize >= 512) {
+            if (ActorAgent::Any == type)
+                setMimetype (MimeType::findByContent (data.data (), 512));
+            if (!validDataFormat (type, data)) {
+                data.resize (0);
+                job->kill (false); // not quiet, wants jobResult
+            }
         }
     }
 }
