@@ -455,7 +455,8 @@ static gboolean gstPollForStateChange (GstElement *element, GstState state, gint
                 gchar *debug = NULL;
                 GError *gsterror = NULL;
                 gst_message_parse_error (message, &gsterror, &debug);
-                fprintf (stderr, "Error: %s (%s)\n", gsterror->message, debug);
+                fprintf (stderr, "Error: %s (%s)\n",
+                        gsterror->message, debug ? debug : "-");
                 gst_message_unref (message);
                 g_error_free (gsterror);
                 g_free (debug);
