@@ -108,11 +108,25 @@ KMPLAYER_NO_EXPORT void RSS::Item::closed () {
                     break;
             }
         }
-        if (group)
-            group->addSummary (this, NULL);
         if (enclosure) {
             enclosure->setCaption (title);
             enclosure->m_description = description;
+            int content_links = 0;
+            if (group) {
+                for (Node *c = group->firstChild (); c; ) {
+                    Node *next = c->nextSibling ();
+                    if (ATOM::id_node_media_content == c->id) {
+                        Mrl *mrl = c->mrl ();
+                        if (mrl && mrl->src == enclosure->src)
+                            group->removeChild (c);
+                        else if (!mrl->src.isEmpty ())
+                            content_links++;
+                    }
+                    c = next;
+                }
+                if (!content_links)
+                    removeChild (group);
+            }
         }
         summary_added = true;
     }
