@@ -393,9 +393,7 @@ static bool needsScreenBlanking (Application *app) {
     return app->top_most_window &&
         CONTROL(app)->playlist_data->current &&
         CONTROL(app)->playlist_data->document->state != Node::state_deferred &&
-        (CONTROL(app)->playlist_data->current->id == SMIL::id_node_smil ||
-         (CONTROL(app)->process ()->playing () &&
-          CONTROL(app)->process ()->hasVideo ()));
+        app->fullscreen;
 }
 
 gboolean cb_blankingTimer (void *p) {
@@ -779,7 +777,6 @@ bool Control::setCurrent (NodePtr n) {
         }
         app_insert_location (m_app, (const char *)url);
     }
-    app_update_screen_blanking (m_app);
     return true;
 }
 
@@ -1418,10 +1415,11 @@ void app_set_suspend (Application *a, bool suspend) {
              CONTROL(a)->process ()->hasVideo ())) {
         if (pd->document->state == Node::state_deferred) {
             if (!suspend)
-                ; // do nothing  a->playlist_data->document->undefer ();
+                pd->document->undefer ();
         } else if (suspend)
             pd->document->defer ();
     }
+    app_update_screen_blanking (a);
 }
 
 static bool locationbar_initialized;
@@ -1776,6 +1774,7 @@ void Control::videoDetected ()
         updateViewAreaSizes ();
     }
     app_full_screen (m_app);
+    app_update_screen_blanking (m_app);
 }
 
 static gboolean downloadPageDestroyed (GtkObject *, Application *app)
@@ -1947,7 +1946,6 @@ void showDownloadPage (GtkMenuItem *, Application *app)
     gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (
                 GTK_TREE_VIEW(app->downloads_view)));
     gtk_widget_show_all (GTK_WIDGET (app->window_downloads));
-    app_update_screen_blanking (app);
 }
 
 /*
