@@ -818,7 +818,6 @@ namespace SMIL {
     class Animate;
     class AnimateMotion;
     class MediaType;
-    class ImageMediaType;
     class TextMediaType;
     class RefMediaType;
     class Brush;
@@ -858,7 +857,6 @@ public:
     virtual void visit (SMIL::AnimateBase *);
     virtual void visit (SMIL::PriorityClass *);
     virtual void visit (SMIL::MediaType *);
-    virtual void visit (SMIL::ImageMediaType *);
     virtual void visit (SMIL::TextMediaType *);
     virtual void visit (SMIL::RefMediaType *);
     virtual void visit (SMIL::Brush *);
