@@ -492,7 +492,7 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
                 }
                 cmdline += Char (' ');
                 found_attr = true;
-            } else if (a->name () == StringPool::attr_panzoom) {
+            } else if (a->name () == Ids::attr_panzoom) {
                 String coord[4];
                 if (Mrl::parsePanZoomString (a->value (), coord)) {
                     cmdline += String ("-vf crop=") +
@@ -843,11 +843,11 @@ KMPLAYER_NO_EXPORT bool NpPlayer::play (NodePtr node) {
         for (Node *n = mrl->firstChild (); n; n = n->nextSibling ()) {
             /*if (n->id == KMPlayer::id_node_param) {
                 KMPlayer::Element *e = static_cast <KMPlayer::Element *> (n);
-                String name = e->getAttribute (KMPlayer::StringPool::attr_name);
+                String name = e->getAttribute (KMPlayer::Ids::attr_name);
                 if (!g_tree_lookup (params, (const char *) name))
                     g_tree_insert (params,
                             strdup ((const char *) name),
-                            strdup ((const char *) e->getAttribute (KMPlayer::StringPool::attr_value)));
+                            strdup ((const char *) e->getAttribute (KMPlayer::Ids::attr_value)));
             } else*/ if (n->id == KMPlayer::id_node_html_embed) {
                 KMPlayer::Element *e = static_cast <KMPlayer::Element *> (n);
                 Attribute *a = e->attributes ().first ();
@@ -916,8 +916,8 @@ Download::~Download ()
 void Download::closed ()
 {
     file = getAttribute ("file");
-    uri = getAttribute (StringPool::attr_src);
-    title = getAttribute (StringPool::attr_title);
+    uri = getAttribute (Ids::attr_src);
+    title = getAttribute (Ids::attr_title);
     Element::closed ();
 }
 
@@ -1066,8 +1066,8 @@ void KMPLAYER_NO_EXPORT Downloader::createDownload (const String &url, const Str
                 NodePtr doc = m_notify->downloads ();
                 Element *n = new Download (doc, m_notify, fd);
                 doc->appendChild (n);
-                n->setAttribute (StringPool::attr_src, url);
-                n->setAttribute (StringPool::attr_title, title);
+                n->setAttribute (Ids::attr_src, url);
+                n->setAttribute (Ids::attr_title, title);
                 n->setAttribute ("file", filename);
                 n->closed ();
                 n->begin ();
